@@ -43,10 +43,9 @@ class Command(BaseCommand):
                 json.dumps(project.environment.marker_environment, indent=2)
             )
         else:
-
             for name, value in zip(
                 [
-                    f"[bold cyan]{key}[/]:"
+                    f"[primary]{key}[/]:"
                     for key in [
                         "PDM version",
                         "Python Interpreter",
